@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2024 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2025 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,9 +20,9 @@
 #define BUILD_WITH_CMAKE 1
 
 #define VERSION_MAJOR 1
-#define VERSION_MINOR 9
-#define VERSION_PATCH 1
-#define VERSION_STR "1.9.1"
+#define VERSION_MINOR 10
+#define VERSION_PATCH 0
+#define VERSION_STR "1.10.0"
 #define VERSION_EXTRA ""
 
 /* #undef _GLIBCXX_DEBUG */
@@ -43,6 +43,8 @@
 #define HAVE_TCSETATTR 1
 /* #undef HAVE_GETPASSPHRASE */
 #define HAVE_CLOCK_GETTIME 1
+#define ZNC_HAVE_GETHOSTNAME 1
+#define ZNC_HAVE_UNAME 1
 
 #define HAVE_ICU 1
 #define U_USING_ICU_NAMESPACE 1
